indelstopo: Analyzing topological properties of sets of words using the Insertion Chain Complex framework
=========================================================================================================

Description
-----------

Python package to analyze topological properties of sets of words when their main source of variation are insertions and deletions, using the Insertion Chain Complex framework

License
-------

MIT

Upstream Contact
----------------

- https://pypi.org/project/InDelsTopo/
- https://github.com/passagemath/passagemath-pkg-InDelsTopo
